function [residual, g1, g2, g3] = housing_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(70, 1);
T82 = y(96)*y(95)*params(15)/(1+y(25));
T128 = y(42)/y(9);
T132 = 1-params(13)/2*(T128-1)^2;
T140 = y(94)*params(13)*params(1)*y(101)/y(50);
T143 = y(99)/y(42)-1;
T144 = T140*T143;
T145 = (y(99)/y(42))^2;
T147 = 1-T144*T145;
T150 = T132-T128*params(13)*(T128-1);
T161 = y(43)/y(10);
T165 = 1-params(14)/2*(T161-1)^2;
T171 = y(95)*params(1)*y(101)/y(50)*params(14);
T174 = y(100)/y(43)-1;
T175 = T171*T174;
T176 = (y(100)/y(43))^2;
T178 = 1-T175*T176;
T181 = T165-T161*params(14)*(T161-1);
T247 = y(56)*y(8)^params(3);
T252 = y(39)^params(6)*y(40)^(1-params(6));
T254 = T252^(1-params(3));
T255 = T247*T254;
T300 = (steady_state(3))*(y(30)/(steady_state(10)))^params(17);
T304 = (y(44)/(steady_state(24)))^params(18);
T305 = T300*T304;
T307 = T305^(1-params(16));
T600 = getPowerDeriv(y(31)/y(30),(-params(11)),1);
T743 = (-(params(13)/2*(-y(42))/(y(9)*y(9))*2*(T128-1)));
T760 = (-(params(13)/2*2*(T128-1)*1/y(9)));
T802 = (-(params(14)/2*(-y(43))/(y(10)*y(10))*2*(T161-1)));
T819 = (-(params(14)/2*2*(T161-1)*1/y(10)));
lhs =y(61);
rhs =(steady_state(41));
residual(1)= lhs-rhs;
lhs =y(50);
rhs =y(54)*(1-params(10))/(y(22)-params(10)*y(2));
residual(2)= lhs-rhs;
lhs =y(51);
rhs =y(54)*(1-params(10))/(y(21)-params(10)*y(1));
residual(3)= lhs-rhs;
lhs =y(52);
rhs =y(61)*y(55)/y(29);
residual(4)= lhs-rhs;
lhs =y(53);
rhs =y(61)*y(55)/y(28);
residual(5)= lhs-rhs;
lhs =y(50);
rhs =params(1)*y(101)*y(23)/y(96);
residual(6)= lhs-rhs;
lhs =y(50)*y(26);
rhs =params(1)*y(101)*(y(92)+y(94)*(1-params(4)));
residual(7)= lhs-rhs;
lhs =y(50)*y(27);
rhs =y(52)+y(101)*params(1)*y(58)*(1-params(26))*y(95);
residual(8)= lhs-rhs;
lhs =y(51)*y(27);
rhs =y(53)+y(58)*(y(95)*(1-params(26))*params(2)*y(102)+y(51)*y(35)*T82);
residual(9)= lhs-rhs;
lhs =y(35);
rhs =1-params(2)*y(102)/y(51)*(1+y(25))/y(96);
residual(10)= lhs-rhs;
lhs =y(21);
rhs =y(38)*y(39)+y(36)-y(27)*(y(28)-(1-params(26))*y(5))-(1+y(4))*y(7)/y(30);
residual(11)= lhs-rhs;
lhs =y(36);
rhs =y(96)*y(28)*y(95)*params(15)/(1+y(25));
residual(12)= lhs-rhs;
lhs =y(93);
rhs =y(91)-1;
residual(13)= lhs-rhs;
lhs =y(41);
rhs =(1-params(4))*y(8)+y(42)*y(59)*T132;
residual(14)= lhs-rhs;
lhs =y(26);
rhs =T147/T150;
residual(15)= lhs-rhs;
lhs =y(48);
rhs =(1-params(26))*y(13)+y(43)*y(60)*T165;
residual(16)= lhs-rhs;
lhs =y(27);
rhs =T178/T181;
residual(17)= lhs-rhs;
lhs =y(30);
rhs =(params(8)+(1-params(8))*y(31)^(1-params(11)))^(1/(1-params(11)));
residual(18)= lhs-rhs;
lhs =y(31);
rhs =y(30)*params(11)/(params(11)-1)*y(32)/y(33);
residual(19)= lhs-rhs;
lhs =y(32);
rhs =y(50)*y(45)*y(44)+params(1)*params(8)*y(96)^params(11)*y(97);
residual(20)= lhs-rhs;
lhs =y(33);
rhs =y(50)*y(44)+params(1)*params(8)*y(96)^(params(11)-1)*y(98);
residual(21)= lhs-rhs;
lhs =y(34);
rhs =(1-params(8))*(y(31)/y(30))^(-params(11))+params(8)*y(30)^params(11)*y(6);
residual(22)= lhs-rhs;
lhs =y(37);
rhs =params(27)*y(40)^params(9)/y(50);
residual(23)= lhs-rhs;
lhs =y(38);
rhs =params(27)*y(39)^params(9)/y(51);
residual(24)= lhs-rhs;
lhs =y(44);
rhs =T255/y(34);
residual(25)= lhs-rhs;
lhs =y(24);
rhs =y(45)*params(3)*y(44)/y(8);
residual(26)= lhs-rhs;
lhs =y(38)*y(39);
rhs =y(44)*y(45)*params(6)*(1-params(3));
residual(27)= lhs-rhs;
lhs =y(37)*y(40);
rhs =y(44)*y(45)*(1-params(6))*(1-params(3));
residual(28)= lhs-rhs;
lhs =y(44);
rhs =y(49)+y(26)*(y(41)-(1-params(4))*y(8))+y(27)*(y(48)-(1-params(26))*y(13))+y(47);
residual(29)= lhs-rhs;
lhs =y(49);
rhs =y(22)+y(21);
residual(30)= lhs-rhs;
lhs =y(48);
rhs =y(29)+y(28);
residual(31)= lhs-rhs;
lhs =y(46);
rhs =y(47)+y(3)*y(11)/y(30);
residual(32)= lhs-rhs;
lhs =y(23);
rhs =y(3)^params(16)*T307*y(57);
residual(33)= lhs-rhs;
lhs =log(y(47));
rhs =params(19)*log(y(12))+(1-params(19))*log((steady_state(27)))+x(it_, 1);
residual(34)= lhs-rhs;
lhs =log(y(57));
rhs =params(20)*log(y(17))+x(it_, 2);
residual(35)= lhs-rhs;
lhs =log(y(54));
rhs =params(21)*log(y(14))+x(it_, 3);
residual(36)= lhs-rhs;
lhs =log(y(55));
rhs =params(22)*log(y(15))+x(it_, 4);
residual(37)= lhs-rhs;
lhs =log(y(56));
rhs =params(23)*log(y(16))+x(it_, 5);
residual(38)= lhs-rhs;
lhs =log(y(58));
rhs =params(23)*log(y(18))+x(it_, 6);
residual(39)= lhs-rhs;
lhs =log(y(59));
rhs =params(23)*log(y(19))+x(it_, 7);
residual(40)= lhs-rhs;
lhs =log(y(60));
rhs =params(23)*log(y(20))+x(it_, 8);
residual(41)= lhs-rhs;
lhs =y(63);
rhs =y(36)/(y(38)*y(39));
residual(42)= lhs-rhs;
lhs =y(64);
rhs =y(36)/(y(38)*y(39));
residual(43)= lhs-rhs;
lhs =y(65);
rhs =y(36)/y(7)-1;
residual(44)= lhs-rhs;
lhs =y(66);
rhs =y(36)/y(44);
residual(45)= lhs-rhs;
lhs =y(67);
rhs =y(25)-y(23);
residual(46)= lhs-rhs;
lhs =y(62);
rhs =y(44)/(steady_state(24))-1;
residual(47)= lhs-rhs;
lhs =y(68);
rhs =y(49)/(steady_state(29))-1;
residual(48)= lhs-rhs;
lhs =y(69);
rhs =y(43)/(steady_state(23))-1;
residual(49)= lhs-rhs;
lhs =y(70);
rhs =y(42)/(steady_state(22))-1;
residual(50)= lhs-rhs;
lhs =y(71);
rhs =y(27)/(steady_state(7))-1;
residual(51)= lhs-rhs;
lhs =y(72);
rhs =y(26)/(steady_state(6))-1;
residual(52)= lhs-rhs;
lhs =y(73);
rhs =y(36)/(steady_state(16))-1;
residual(53)= lhs-rhs;
lhs =y(74);
rhs =y(48)/(steady_state(28))-1;
residual(54)= lhs-rhs;
lhs =y(75);
rhs =y(28)/(steady_state(8))-1;
residual(55)= lhs-rhs;
lhs =y(76);
rhs =y(29)/(steady_state(9))-1;
residual(56)= lhs-rhs;
lhs =y(77);
rhs =y(41)/(steady_state(21))-1;
residual(57)= lhs-rhs;
lhs =y(78);
rhs =y(63)/(steady_state(43))-1;
residual(58)= lhs-rhs;
lhs =y(79);
rhs =y(64)/(steady_state(44))-1;
residual(59)= lhs-rhs;
lhs =y(80);
rhs =y(66)/(steady_state(46))-1;
residual(60)= lhs-rhs;
lhs =y(87);
rhs =y(21)/(steady_state(1))-1;
residual(61)= lhs-rhs;
lhs =y(88);
rhs =y(22)/(steady_state(2))-1;
residual(62)= lhs-rhs;
lhs =y(89);
rhs =y(39)/(steady_state(19))-1;
residual(63)= lhs-rhs;
lhs =y(90);
rhs =y(40)/(steady_state(20))-1;
residual(64)= lhs-rhs;
lhs =y(81);
rhs =(y(23)-(y(30)-1))*4;
residual(65)= lhs-rhs;
lhs =y(82);
rhs =4*(y(23)-1);
residual(66)= lhs-rhs;
lhs =y(83);
rhs =(y(30)-1)*4;
residual(67)= lhs-rhs;
lhs =y(84);
rhs =y(23)*4;
residual(68)= lhs-rhs;
lhs =y(85);
rhs =y(23)*4;
residual(69)= lhs-rhs;
lhs =y(86);
rhs =y(25)*4;
residual(70)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(70, 110);

  %
  % Jacobian matrix
  %

  g1(1,61)=1;
  g1(2,2)=(-((-(y(54)*(1-params(10))*(-params(10))))/((y(22)-params(10)*y(2))*(y(22)-params(10)*y(2)))));
  g1(2,22)=(-((-(y(54)*(1-params(10))))/((y(22)-params(10)*y(2))*(y(22)-params(10)*y(2)))));
  g1(2,50)=1;
  g1(2,54)=(-((1-params(10))/(y(22)-params(10)*y(2))));
  g1(3,1)=(-((-(y(54)*(1-params(10))*(-params(10))))/((y(21)-params(10)*y(1))*(y(21)-params(10)*y(1)))));
  g1(3,21)=(-((-(y(54)*(1-params(10))))/((y(21)-params(10)*y(1))*(y(21)-params(10)*y(1)))));
  g1(3,51)=1;
  g1(3,54)=(-((1-params(10))/(y(21)-params(10)*y(1))));
  g1(4,29)=(-((-(y(61)*y(55)))/(y(29)*y(29))));
  g1(4,52)=1;
  g1(4,55)=(-(y(61)/y(29)));
  g1(4,61)=(-(y(55)/y(29)));
  g1(5,28)=(-((-(y(61)*y(55)))/(y(28)*y(28))));
  g1(5,53)=1;
  g1(5,55)=(-(y(61)/y(28)));
  g1(5,61)=(-(y(55)/y(28)));
  g1(6,23)=(-(params(1)*y(101)*1/y(96)));
  g1(6,96)=(-(params(1)*y(101)*(-y(23))/(y(96)*y(96))));
  g1(6,50)=1;
  g1(6,101)=(-(params(1)*y(23)/y(96)));
  g1(7,92)=(-(params(1)*y(101)));
  g1(7,26)=y(50);
  g1(7,94)=(-(params(1)*y(101)*(1-params(4))));
  g1(7,50)=y(26);
  g1(7,101)=(-(params(1)*(y(92)+y(94)*(1-params(4)))));
  g1(8,27)=y(50);
  g1(8,95)=(-(y(101)*params(1)*y(58)*(1-params(26))));
  g1(8,50)=y(27);
  g1(8,101)=(-(params(1)*y(58)*(1-params(26))*y(95)));
  g1(8,52)=(-1);
  g1(8,58)=(-(y(101)*y(95)*params(1)*(1-params(26))));
  g1(9,25)=(-(y(58)*y(51)*y(35)*(-(y(96)*y(95)*params(15)))/((1+y(25))*(1+y(25)))));
  g1(9,27)=y(51);
  g1(9,95)=(-(y(58)*((1-params(26))*params(2)*y(102)+y(51)*y(35)*y(96)*params(15)/(1+y(25)))));
  g1(9,96)=(-(y(58)*y(51)*y(35)*y(95)*params(15)/(1+y(25))));
  g1(9,35)=(-(y(58)*y(51)*T82));
  g1(9,51)=y(27)-y(58)*y(35)*T82;
  g1(9,102)=(-(y(58)*y(95)*(1-params(26))*params(2)));
  g1(9,53)=(-1);
  g1(9,58)=(-(y(95)*(1-params(26))*params(2)*y(102)+y(51)*y(35)*T82));
  g1(10,25)=params(2)*y(102)/y(51)*1/y(96);
  g1(10,96)=params(2)*y(102)/y(51)*(-(1+y(25)))/(y(96)*y(96));
  g1(10,35)=1;
  g1(10,51)=(1+y(25))/y(96)*params(2)*(-y(102))/(y(51)*y(51));
  g1(10,102)=(1+y(25))/y(96)*params(2)*1/y(51);
  g1(11,21)=1;
  g1(11,4)=y(7)/y(30);
  g1(11,27)=y(28)-(1-params(26))*y(5);
  g1(11,5)=y(27)*(-(1-params(26)));
  g1(11,28)=y(27);
  g1(11,30)=(1+y(4))*(-y(7))/(y(30)*y(30));
  g1(11,7)=(1+y(4))*1/y(30);
  g1(11,36)=(-1);
  g1(11,38)=(-y(39));
  g1(11,39)=(-y(38));
  g1(12,25)=(-((-(y(96)*y(28)*y(95)*params(15)))/((1+y(25))*(1+y(25)))));
  g1(12,95)=(-(y(96)*y(28)*params(15)/(1+y(25))));
  g1(12,28)=(-T82);
  g1(12,96)=(-(y(28)*y(95)*params(15)/(1+y(25))));
  g1(12,36)=1;
  g1(13,91)=(-1);
  g1(13,93)=1;
  g1(14,8)=(-(1-params(4)));
  g1(14,41)=1;
  g1(14,9)=(-(y(42)*y(59)*T743));
  g1(14,42)=(-(y(59)*T132+y(42)*y(59)*T760));
  g1(14,59)=(-(y(42)*T132));
  g1(15,26)=1;
  g1(15,94)=(-((-(T145*params(13)*params(1)*y(101)/y(50)*T143))/T150));
  g1(15,9)=(-((-(T147*(T743-(params(13)*(T128-1)*(-y(42))/(y(9)*y(9))+T128*params(13)*(-y(42))/(y(9)*y(9))))))/(T150*T150)));
  g1(15,42)=(-((T150*(-(T145*T140*(-y(99))/(y(42)*y(42))+T144*(-y(99))/(y(42)*y(42))*2*y(99)/y(42)))-T147*(T760-(params(13)*(T128-1)*1/y(9)+T128*params(13)*1/y(9))))/(T150*T150)));
  g1(15,99)=(-((-(T145*T140*1/y(42)+T144*2*y(99)/y(42)*1/y(42)))/T150));
  g1(15,50)=(-((-(T145*T143*y(94)*params(13)*params(1)*(-y(101))/(y(50)*y(50))))/T150));
  g1(15,101)=(-((-(T145*T143*y(94)*params(13)*params(1)*1/y(50)))/T150));
  g1(16,10)=(-(y(43)*y(60)*T802));
  g1(16,43)=(-(y(60)*T165+y(43)*y(60)*T819));
  g1(16,13)=(-(1-params(26)));
  g1(16,48)=1;
  g1(16,60)=(-(y(43)*T165));
  g1(17,27)=1;
  g1(17,95)=(-((-(T176*params(1)*y(101)/y(50)*params(14)*T174))/T181));
  g1(17,10)=(-((-(T178*(T802-(params(14)*(T161-1)*(-y(43))/(y(10)*y(10))+T161*params(14)*(-y(43))/(y(10)*y(10))))))/(T181*T181)));
  g1(17,43)=(-((T181*(-(T176*T171*(-y(100))/(y(43)*y(43))+T175*(-y(100))/(y(43)*y(43))*2*y(100)/y(43)))-T178*(T819-(params(14)*(T161-1)*1/y(10)+T161*params(14)*1/y(10))))/(T181*T181)));
  g1(17,100)=(-((-(T176*T171*1/y(43)+T175*2*y(100)/y(43)*1/y(43)))/T181));
  g1(17,50)=(-((-(T176*T174*y(95)*params(14)*params(1)*(-y(101))/(y(50)*y(50))))/T181));
  g1(17,101)=(-((-(T176*T174*y(95)*params(14)*params(1)*1/y(50)))/T181));
  g1(18,30)=1;
  g1(18,31)=(-((1-params(8))*getPowerDeriv(y(31),1-params(11),1)*getPowerDeriv(params(8)+(1-params(8))*y(31)^(1-params(11)),1/(1-params(11)),1)));
  g1(19,30)=(-(params(11)/(params(11)-1)*y(32)/y(33)));
  g1(19,31)=1;
  g1(19,32)=(-(y(30)*params(11)/(params(11)-1)*1/y(33)));
  g1(19,33)=(-(y(30)*params(11)/(params(11)-1)*(-y(32))/(y(33)*y(33))));
  g1(20,96)=(-(y(97)*params(1)*params(8)*getPowerDeriv(y(96),params(11),1)));
  g1(20,32)=1;
  g1(20,97)=(-(params(1)*params(8)*y(96)^params(11)));
  g1(20,44)=(-(y(50)*y(45)));
  g1(20,45)=(-(y(50)*y(44)));
  g1(20,50)=(-(y(45)*y(44)));
  g1(21,96)=(-(y(98)*params(1)*params(8)*getPowerDeriv(y(96),params(11)-1,1)));
  g1(21,33)=1;
  g1(21,98)=(-(params(1)*params(8)*y(96)^(params(11)-1)));
  g1(21,44)=(-y(50));
  g1(21,50)=(-y(44));
  g1(22,30)=(-((1-params(8))*(-y(31))/(y(30)*y(30))*T600+y(6)*params(8)*getPowerDeriv(y(30),params(11),1)));
  g1(22,31)=(-((1-params(8))*T600*1/y(30)));
  g1(22,6)=(-(params(8)*y(30)^params(11)));
  g1(22,34)=1;
  g1(23,37)=1;
  g1(23,40)=(-(params(27)*getPowerDeriv(y(40),params(9),1)/y(50)));
  g1(23,50)=(-((-(params(27)*y(40)^params(9)))/(y(50)*y(50))));
  g1(24,38)=1;
  g1(24,39)=(-(params(27)*getPowerDeriv(y(39),params(9),1)/y(51)));
  g1(24,51)=(-((-(params(27)*y(39)^params(9)))/(y(51)*y(51))));
  g1(25,34)=(-((-T255)/(y(34)*y(34))));
  g1(25,39)=(-(T247*y(40)^(1-params(6))*getPowerDeriv(y(39),params(6),1)*getPowerDeriv(T252,1-params(3),1)/y(34)));
  g1(25,40)=(-(T247*getPowerDeriv(T252,1-params(3),1)*y(39)^params(6)*getPowerDeriv(y(40),1-params(6),1)/y(34)));
  g1(25,8)=(-(T254*y(56)*getPowerDeriv(y(8),params(3),1)/y(34)));
  g1(25,44)=1;
  g1(25,56)=(-(y(8)^params(3)*T254/y(34)));
  g1(26,24)=1;
  g1(26,8)=(-(y(45)*params(3)*(-y(44))/(y(8)*y(8))));
  g1(26,44)=(-(y(45)*params(3)*1/y(8)));
  g1(26,45)=(-(params(3)*y(44)/y(8)));
  g1(27,38)=y(39);
  g1(27,39)=y(38);
  g1(27,44)=(-(y(45)*params(6)*(1-params(3))));
  g1(27,45)=(-(y(44)*params(6)*(1-params(3))));
  g1(28,37)=y(40);
  g1(28,40)=y(37);
  g1(28,44)=(-(y(45)*(1-params(6))*(1-params(3))));
  g1(28,45)=(-(y(44)*(1-params(6))*(1-params(3))));
  g1(29,26)=(-(y(41)-(1-params(4))*y(8)));
  g1(29,27)=(-(y(48)-(1-params(26))*y(13)));
  g1(29,8)=(-(y(26)*(-(1-params(4)))));
  g1(29,41)=(-y(26));
  g1(29,44)=1;
  g1(29,47)=(-1);
  g1(29,13)=(-(y(27)*(-(1-params(26)))));
  g1(29,48)=(-y(27));
  g1(29,49)=(-1);
  g1(30,21)=(-1);
  g1(30,22)=(-1);
  g1(30,49)=1;
  g1(31,28)=(-1);
  g1(31,29)=(-1);
  g1(31,48)=1;
  g1(32,3)=(-(y(11)/y(30)));
  g1(32,30)=(-((-(y(3)*y(11)))/(y(30)*y(30))));
  g1(32,11)=(-(y(3)/y(30)));
  g1(32,46)=1;
  g1(32,47)=(-1);
  g1(33,3)=(-(y(57)*T307*getPowerDeriv(y(3),params(16),1)));
  g1(33,23)=1;
  g1(33,30)=(-(y(57)*y(3)^params(16)*T304*(steady_state(3))*1/(steady_state(10))*getPowerDeriv(y(30)/(steady_state(10)),params(17),1)*getPowerDeriv(T305,1-params(16),1)));
  g1(33,44)=(-(y(57)*y(3)^params(16)*getPowerDeriv(T305,1-params(16),1)*T300*1/(steady_state(24))*getPowerDeriv(y(44)/(steady_state(24)),params(18),1)));
  g1(33,57)=(-(y(3)^params(16)*T307));
  g1(34,12)=(-(params(19)*1/y(12)));
  g1(34,47)=1/y(47);
  g1(34,103)=(-1);
  g1(35,17)=(-(params(20)*1/y(17)));
  g1(35,57)=1/y(57);
  g1(35,104)=(-1);
  g1(36,14)=(-(params(21)*1/y(14)));
  g1(36,54)=1/y(54);
  g1(36,105)=(-1);
  g1(37,15)=(-(params(22)*1/y(15)));
  g1(37,55)=1/y(55);
  g1(37,106)=(-1);
  g1(38,16)=(-(params(23)*1/y(16)));
  g1(38,56)=1/y(56);
  g1(38,107)=(-1);
  g1(39,18)=(-(params(23)*1/y(18)));
  g1(39,58)=1/y(58);
  g1(39,108)=(-1);
  g1(40,19)=(-(params(23)*1/y(19)));
  g1(40,59)=1/y(59);
  g1(40,109)=(-1);
  g1(41,20)=(-(params(23)*1/y(20)));
  g1(41,60)=1/y(60);
  g1(41,110)=(-1);
  g1(42,36)=(-(1/(y(38)*y(39))));
  g1(42,38)=(-((-(y(39)*y(36)))/(y(38)*y(39)*y(38)*y(39))));
  g1(42,39)=(-((-(y(38)*y(36)))/(y(38)*y(39)*y(38)*y(39))));
  g1(42,63)=1;
  g1(43,36)=(-(1/(y(38)*y(39))));
  g1(43,38)=(-((-(y(39)*y(36)))/(y(38)*y(39)*y(38)*y(39))));
  g1(43,39)=(-((-(y(38)*y(36)))/(y(38)*y(39)*y(38)*y(39))));
  g1(43,64)=1;
  g1(44,7)=(-((-y(36))/(y(7)*y(7))));
  g1(44,36)=(-(1/y(7)));
  g1(44,65)=1;
  g1(45,36)=(-(1/y(44)));
  g1(45,44)=(-((-y(36))/(y(44)*y(44))));
  g1(45,66)=1;
  g1(46,23)=1;
  g1(46,25)=(-1);
  g1(46,67)=1;
  g1(47,44)=(-(1/(steady_state(24))));
  g1(47,62)=1;
  g1(48,49)=(-(1/(steady_state(29))));
  g1(48,68)=1;
  g1(49,43)=(-(1/(steady_state(23))));
  g1(49,69)=1;
  g1(50,42)=(-(1/(steady_state(22))));
  g1(50,70)=1;
  g1(51,27)=(-(1/(steady_state(7))));
  g1(51,71)=1;
  g1(52,26)=(-(1/(steady_state(6))));
  g1(52,72)=1;
  g1(53,36)=(-(1/(steady_state(16))));
  g1(53,73)=1;
  g1(54,48)=(-(1/(steady_state(28))));
  g1(54,74)=1;
  g1(55,28)=(-(1/(steady_state(8))));
  g1(55,75)=1;
  g1(56,29)=(-(1/(steady_state(9))));
  g1(56,76)=1;
  g1(57,41)=(-(1/(steady_state(21))));
  g1(57,77)=1;
  g1(58,63)=(-(1/(steady_state(43))));
  g1(58,78)=1;
  g1(59,64)=(-(1/(steady_state(44))));
  g1(59,79)=1;
  g1(60,66)=(-(1/(steady_state(46))));
  g1(60,80)=1;
  g1(61,21)=(-(1/(steady_state(1))));
  g1(61,87)=1;
  g1(62,22)=(-(1/(steady_state(2))));
  g1(62,88)=1;
  g1(63,39)=(-(1/(steady_state(19))));
  g1(63,89)=1;
  g1(64,40)=(-(1/(steady_state(20))));
  g1(64,90)=1;
  g1(65,23)=(-4);
  g1(65,30)=4;
  g1(65,81)=1;
  g1(66,23)=(-4);
  g1(66,82)=1;
  g1(67,30)=(-4);
  g1(67,83)=1;
  g1(68,23)=(-4);
  g1(68,84)=1;
  g1(69,23)=(-4);
  g1(69,85)=1;
  g1(70,25)=(-4);
  g1(70,86)=1;
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],70,12100);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],70,1331000);
end
end
