function [residual, g1, g2] = housing_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                     columns: variables in declaration order
%                                                     rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 70, 1);

%
% Model equations
%

T76 = y(10)*y(7)*params(15)/(1+y(5));
T188 = y(36)*y(21)^params(3);
T193 = y(19)^params(6)*y(20)^(1-params(6));
T195 = T193^(1-params(3));
T196 = T188*T195;
T232 = y(3)^params(16);
T237 = (y(10)/(y(10)))^params(17);
T242 = (y(24)/(y(24)))^params(18);
T245 = ((y(3))*T237*T242)^(1-params(16));
T437 = 1/y(10);
T444 = getPowerDeriv((y(3))*T237*T242,1-params(16),1);
T541 = getPowerDeriv(y(11)/y(10),(-params(11)),1);
lhs =y(41);
rhs =(y(41));
residual(1)= lhs-rhs;
lhs =y(30);
rhs =y(34)*(1-params(10))/(y(2)-params(10)*y(2));
residual(2)= lhs-rhs;
lhs =y(31);
rhs =y(34)*(1-params(10))/(y(1)-params(10)*y(1));
residual(3)= lhs-rhs;
lhs =y(32);
rhs =y(41)*y(35)/y(9);
residual(4)= lhs-rhs;
lhs =y(33);
rhs =y(41)*y(35)/y(8);
residual(5)= lhs-rhs;
lhs =y(30);
rhs =y(30)*params(1)*y(3)/y(10);
residual(6)= lhs-rhs;
lhs =y(30)*y(6);
rhs =y(30)*params(1)*(y(4)+y(6)*(1-params(4)));
residual(7)= lhs-rhs;
lhs =y(30)*y(7);
rhs =y(32)+y(30)*y(7)*params(1)*y(38)*(1-params(26));
residual(8)= lhs-rhs;
lhs =y(31)*y(7);
rhs =y(33)+y(38)*(y(31)*y(7)*(1-params(26))*params(2)+y(31)*y(15)*T76);
residual(9)= lhs-rhs;
lhs =y(15);
rhs =1-params(2)*(1+y(5))/y(10);
residual(10)= lhs-rhs;
lhs =y(1);
rhs =y(18)*y(19)+y(16)-y(7)*(y(8)-y(8)*(1-params(26)))-(1+y(5))*y(16)/y(10);
residual(11)= lhs-rhs;
lhs =y(16);
rhs =y(10)*y(8)*y(7)*params(15)/(1+y(5));
residual(12)= lhs-rhs;
lhs =y(5);
rhs =y(3)-1;
residual(13)= lhs-rhs;
lhs =y(21);
rhs =(1-params(4))*y(21)+y(22)*y(39);
residual(14)= lhs-rhs;
lhs =y(6);
rhs =1;
residual(15)= lhs-rhs;
lhs =y(28);
rhs =(1-params(26))*y(28)+y(23)*y(40);
residual(16)= lhs-rhs;
lhs =y(7);
rhs =1;
residual(17)= lhs-rhs;
lhs =y(10);
rhs =(params(8)+(1-params(8))*y(11)^(1-params(11)))^(1/(1-params(11)));
residual(18)= lhs-rhs;
lhs =y(11);
rhs =y(10)*params(11)/(params(11)-1)*y(12)/y(13);
residual(19)= lhs-rhs;
lhs =y(12);
rhs =y(30)*y(25)*y(24)+y(12)*params(1)*params(8)*y(10)^params(11);
residual(20)= lhs-rhs;
lhs =y(13);
rhs =y(30)*y(24)+y(13)*params(1)*params(8)*y(10)^(params(11)-1);
residual(21)= lhs-rhs;
lhs =y(14);
rhs =(1-params(8))*(y(11)/y(10))^(-params(11))+y(14)*params(8)*y(10)^params(11);
residual(22)= lhs-rhs;
lhs =y(17);
rhs =params(27)*y(20)^params(9)/y(30);
residual(23)= lhs-rhs;
lhs =y(18);
rhs =params(27)*y(19)^params(9)/y(31);
residual(24)= lhs-rhs;
lhs =y(24);
rhs =T196/y(14);
residual(25)= lhs-rhs;
lhs =y(4);
rhs =y(25)*params(3)*y(24)/y(21);
residual(26)= lhs-rhs;
lhs =y(18)*y(19);
rhs =y(24)*y(25)*params(6)*(1-params(3));
residual(27)= lhs-rhs;
lhs =y(17)*y(20);
rhs =y(24)*y(25)*(1-params(6))*(1-params(3));
residual(28)= lhs-rhs;
lhs =y(24);
rhs =y(29)+y(6)*(y(21)-(1-params(4))*y(21))+y(7)*(y(28)-(1-params(26))*y(28))+y(27);
residual(29)= lhs-rhs;
lhs =y(29);
rhs =y(2)+y(1);
residual(30)= lhs-rhs;
lhs =y(28);
rhs =y(9)+y(8);
residual(31)= lhs-rhs;
lhs =y(26);
rhs =y(27)+y(3)*y(26)/y(10);
residual(32)= lhs-rhs;
lhs =y(3);
rhs =T232*T245*y(37);
residual(33)= lhs-rhs;
lhs =log(y(27));
rhs =log(y(27))*params(19)+(1-params(19))*log((y(27)))+x(1);
residual(34)= lhs-rhs;
lhs =log(y(37));
rhs =log(y(37))*params(20)+x(2);
residual(35)= lhs-rhs;
lhs =log(y(34));
rhs =log(y(34))*params(21)+x(3);
residual(36)= lhs-rhs;
lhs =log(y(35));
rhs =log(y(35))*params(22)+x(4);
residual(37)= lhs-rhs;
lhs =log(y(36));
rhs =log(y(36))*params(23)+x(5);
residual(38)= lhs-rhs;
lhs =log(y(38));
rhs =params(23)*log(y(38))+x(6);
residual(39)= lhs-rhs;
lhs =log(y(39));
rhs =params(23)*log(y(39))+x(7);
residual(40)= lhs-rhs;
lhs =log(y(40));
rhs =params(23)*log(y(40))+x(8);
residual(41)= lhs-rhs;
lhs =y(43);
rhs =y(16)/(y(18)*y(19));
residual(42)= lhs-rhs;
lhs =y(44);
rhs =y(16)/(y(18)*y(19));
residual(43)= lhs-rhs;
residual(44) = y(45);
lhs =y(46);
rhs =y(16)/y(24);
residual(45)= lhs-rhs;
lhs =y(47);
rhs =y(5)-y(3);
residual(46)= lhs-rhs;
lhs =y(42);
rhs =y(24)/(y(24))-1;
residual(47)= lhs-rhs;
lhs =y(48);
rhs =y(29)/(y(29))-1;
residual(48)= lhs-rhs;
lhs =y(49);
rhs =y(23)/(y(23))-1;
residual(49)= lhs-rhs;
lhs =y(50);
rhs =y(22)/(y(22))-1;
residual(50)= lhs-rhs;
lhs =y(51);
rhs =y(7)/(y(7))-1;
residual(51)= lhs-rhs;
lhs =y(52);
rhs =y(6)/(y(6))-1;
residual(52)= lhs-rhs;
lhs =y(53);
rhs =y(16)/(y(16))-1;
residual(53)= lhs-rhs;
lhs =y(54);
rhs =y(28)/(y(28))-1;
residual(54)= lhs-rhs;
lhs =y(55);
rhs =y(8)/(y(8))-1;
residual(55)= lhs-rhs;
lhs =y(56);
rhs =y(9)/(y(9))-1;
residual(56)= lhs-rhs;
lhs =y(57);
rhs =y(21)/(y(21))-1;
residual(57)= lhs-rhs;
lhs =y(58);
rhs =y(43)/(y(43))-1;
residual(58)= lhs-rhs;
lhs =y(59);
rhs =y(44)/(y(44))-1;
residual(59)= lhs-rhs;
lhs =y(60);
rhs =y(46)/(y(46))-1;
residual(60)= lhs-rhs;
lhs =y(67);
rhs =y(1)/(y(1))-1;
residual(61)= lhs-rhs;
lhs =y(68);
rhs =y(2)/(y(2))-1;
residual(62)= lhs-rhs;
lhs =y(69);
rhs =y(19)/(y(19))-1;
residual(63)= lhs-rhs;
lhs =y(70);
rhs =y(20)/(y(20))-1;
residual(64)= lhs-rhs;
lhs =y(61);
rhs =(y(3)-(y(10)-1))*4;
residual(65)= lhs-rhs;
lhs =y(62);
rhs =(y(3)-1)*4;
residual(66)= lhs-rhs;
lhs =y(63);
rhs =(y(10)-1)*4;
residual(67)= lhs-rhs;
lhs =y(64);
rhs =y(3)*4;
residual(68)= lhs-rhs;
lhs =y(65);
rhs =y(3)*4;
residual(69)= lhs-rhs;
lhs =y(66);
rhs =y(5)*4;
residual(70)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(70, 70);

  %
  % Jacobian matrix
  %

  g1(2,2)=(-((-((1-params(10))*y(34)*(1-params(10))))/((y(2)-params(10)*y(2))*(y(2)-params(10)*y(2)))));
  g1(2,30)=1;
  g1(2,34)=(-((1-params(10))/(y(2)-params(10)*y(2))));
  g1(3,1)=(-((-((1-params(10))*y(34)*(1-params(10))))/((y(1)-params(10)*y(1))*(y(1)-params(10)*y(1)))));
  g1(3,31)=1;
  g1(3,34)=(-((1-params(10))/(y(1)-params(10)*y(1))));
  g1(4,9)=(-((-(y(41)*y(35)))/(y(9)*y(9))));
  g1(4,32)=1;
  g1(4,35)=(-(y(41)/y(9)));
  g1(4,41)=(-(y(35)/y(9)));
  g1(5,8)=(-((-(y(41)*y(35)))/(y(8)*y(8))));
  g1(5,33)=1;
  g1(5,35)=(-(y(41)/y(8)));
  g1(5,41)=(-(y(35)/y(8)));
  g1(6,3)=(-(y(30)*params(1)*T437));
  g1(6,10)=(-(y(30)*params(1)*(-y(3))/(y(10)*y(10))));
  g1(6,30)=1-params(1)*y(3)/y(10);
  g1(7,4)=(-(y(30)*params(1)));
  g1(7,6)=y(30)-y(30)*params(1)*(1-params(4));
  g1(7,30)=y(6)-params(1)*(y(4)+y(6)*(1-params(4)));
  g1(8,7)=y(30)-y(30)*params(1)*y(38)*(1-params(26));
  g1(8,30)=y(7)-y(7)*params(1)*y(38)*(1-params(26));
  g1(8,32)=(-1);
  g1(8,38)=(-(y(30)*y(7)*params(1)*(1-params(26))));
  g1(9,5)=(-(y(38)*y(31)*y(15)*(-(y(10)*y(7)*params(15)))/((1+y(5))*(1+y(5)))));
  g1(9,7)=y(31)-y(38)*(y(31)*(1-params(26))*params(2)+y(31)*y(15)*y(10)*params(15)/(1+y(5)));
  g1(9,10)=(-(y(38)*y(31)*y(15)*y(7)*params(15)/(1+y(5))));
  g1(9,15)=(-(y(38)*y(31)*T76));
  g1(9,31)=y(7)-y(38)*(y(7)*(1-params(26))*params(2)+y(15)*T76);
  g1(9,33)=(-1);
  g1(9,38)=(-(y(31)*y(7)*(1-params(26))*params(2)+y(31)*y(15)*T76));
  g1(10,5)=params(2)*T437;
  g1(10,10)=params(2)*(-(1+y(5)))/(y(10)*y(10));
  g1(10,15)=1;
  g1(11,1)=1;
  g1(11,5)=y(16)/y(10);
  g1(11,7)=y(8)-y(8)*(1-params(26));
  g1(11,8)=y(7)*(1-(1-params(26)));
  g1(11,10)=(1+y(5))*(-y(16))/(y(10)*y(10));
  g1(11,16)=(-(1-(1+y(5))*T437));
  g1(11,18)=(-y(19));
  g1(11,19)=(-y(18));
  g1(12,5)=(-((-(y(10)*y(8)*y(7)*params(15)))/((1+y(5))*(1+y(5)))));
  g1(12,7)=(-(y(10)*y(8)*params(15)/(1+y(5))));
  g1(12,8)=(-T76);
  g1(12,10)=(-(y(8)*y(7)*params(15)/(1+y(5))));
  g1(12,16)=1;
  g1(13,3)=(-1);
  g1(13,5)=1;
  g1(14,21)=1-(1-params(4));
  g1(14,22)=(-y(39));
  g1(14,39)=(-y(22));
  g1(15,6)=1;
  g1(16,23)=(-y(40));
  g1(16,28)=1-(1-params(26));
  g1(16,40)=(-y(23));
  g1(17,7)=1;
  g1(18,10)=1;
  g1(18,11)=(-((1-params(8))*getPowerDeriv(y(11),1-params(11),1)*getPowerDeriv(params(8)+(1-params(8))*y(11)^(1-params(11)),1/(1-params(11)),1)));
  g1(19,10)=(-(params(11)/(params(11)-1)*y(12)/y(13)));
  g1(19,11)=1;
  g1(19,12)=(-(y(10)*params(11)/(params(11)-1)*1/y(13)));
  g1(19,13)=(-(y(10)*params(11)/(params(11)-1)*(-y(12))/(y(13)*y(13))));
  g1(20,10)=(-(y(12)*params(1)*params(8)*getPowerDeriv(y(10),params(11),1)));
  g1(20,12)=1-params(1)*params(8)*y(10)^params(11);
  g1(20,24)=(-(y(30)*y(25)));
  g1(20,25)=(-(y(30)*y(24)));
  g1(20,30)=(-(y(25)*y(24)));
  g1(21,10)=(-(y(13)*params(1)*params(8)*getPowerDeriv(y(10),params(11)-1,1)));
  g1(21,13)=1-params(1)*params(8)*y(10)^(params(11)-1);
  g1(21,24)=(-y(30));
  g1(21,30)=(-y(24));
  g1(22,10)=(-((1-params(8))*(-y(11))/(y(10)*y(10))*T541+y(14)*params(8)*getPowerDeriv(y(10),params(11),1)));
  g1(22,11)=(-((1-params(8))*T437*T541));
  g1(22,14)=1-params(8)*y(10)^params(11);
  g1(23,17)=1;
  g1(23,20)=(-(params(27)*getPowerDeriv(y(20),params(9),1)/y(30)));
  g1(23,30)=(-((-(params(27)*y(20)^params(9)))/(y(30)*y(30))));
  g1(24,18)=1;
  g1(24,19)=(-(params(27)*getPowerDeriv(y(19),params(9),1)/y(31)));
  g1(24,31)=(-((-(params(27)*y(19)^params(9)))/(y(31)*y(31))));
  g1(25,14)=(-((-T196)/(y(14)*y(14))));
  g1(25,19)=(-(T188*y(20)^(1-params(6))*getPowerDeriv(y(19),params(6),1)*getPowerDeriv(T193,1-params(3),1)/y(14)));
  g1(25,20)=(-(T188*getPowerDeriv(T193,1-params(3),1)*y(19)^params(6)*getPowerDeriv(y(20),1-params(6),1)/y(14)));
  g1(25,21)=(-(T195*y(36)*getPowerDeriv(y(21),params(3),1)/y(14)));
  g1(25,24)=1;
  g1(25,36)=(-(y(21)^params(3)*T195/y(14)));
  g1(26,4)=1;
  g1(26,21)=(-(y(25)*params(3)*(-y(24))/(y(21)*y(21))));
  g1(26,24)=(-(y(25)*params(3)*1/y(21)));
  g1(26,25)=(-(params(3)*y(24)/y(21)));
  g1(27,18)=y(19);
  g1(27,19)=y(18);
  g1(27,24)=(-(y(25)*params(6)*(1-params(3))));
  g1(27,25)=(-(y(24)*params(6)*(1-params(3))));
  g1(28,17)=y(20);
  g1(28,20)=y(17);
  g1(28,24)=(-(y(25)*(1-params(6))*(1-params(3))));
  g1(28,25)=(-(y(24)*(1-params(6))*(1-params(3))));
  g1(29,6)=(-(y(21)-(1-params(4))*y(21)));
  g1(29,7)=(-(y(28)-(1-params(26))*y(28)));
  g1(29,21)=(-(y(6)*(1-(1-params(4)))));
  g1(29,24)=1;
  g1(29,27)=(-1);
  g1(29,28)=(-(y(7)*(1-(1-params(26)))));
  g1(29,29)=(-1);
  g1(30,1)=(-1);
  g1(30,2)=(-1);
  g1(30,29)=1;
  g1(31,8)=(-1);
  g1(31,9)=(-1);
  g1(31,28)=1;
  g1(32,3)=(-(y(26)/y(10)));
  g1(32,10)=(-((-(y(3)*y(26)))/(y(10)*y(10))));
  g1(32,26)=1-y(3)/y(10);
  g1(32,27)=(-1);
  g1(33,3)=1-y(37)*(T245*getPowerDeriv(y(3),params(16),1)+T232*T237*T242*T444);
  g1(33,10)=(-(y(37)*T232*T444*T242*(y(3))*((y(10))-y(10))/((y(10))*(y(10)))*getPowerDeriv(y(10)/(y(10)),params(17),1)));
  g1(33,24)=(-(y(37)*T232*T444*(y(3))*T237*((y(24))-y(24))/((y(24))*(y(24)))*getPowerDeriv(y(24)/(y(24)),params(18),1)));
  g1(33,37)=(-(T232*T245));
  g1(34,27)=1/y(27)-(params(19)*1/y(27)+(1-params(19))*1/(y(27)));
  g1(35,37)=1/y(37)-params(20)*1/y(37);
  g1(36,34)=1/y(34)-params(21)*1/y(34);
  g1(37,35)=1/y(35)-params(22)*1/y(35);
  g1(38,36)=1/y(36)-params(23)*1/y(36);
  g1(39,38)=1/y(38)-params(23)*1/y(38);
  g1(40,39)=1/y(39)-params(23)*1/y(39);
  g1(41,40)=1/y(40)-params(23)*1/y(40);
  g1(42,16)=(-(1/(y(18)*y(19))));
  g1(42,18)=(-((-(y(19)*y(16)))/(y(18)*y(19)*y(18)*y(19))));
  g1(42,19)=(-((-(y(18)*y(16)))/(y(18)*y(19)*y(18)*y(19))));
  g1(42,43)=1;
  g1(43,16)=(-(1/(y(18)*y(19))));
  g1(43,18)=(-((-(y(19)*y(16)))/(y(18)*y(19)*y(18)*y(19))));
  g1(43,19)=(-((-(y(18)*y(16)))/(y(18)*y(19)*y(18)*y(19))));
  g1(43,44)=1;
  g1(44,45)=1;
  g1(45,16)=(-(1/y(24)));
  g1(45,24)=(-((-y(16))/(y(24)*y(24))));
  g1(45,46)=1;
  g1(46,3)=1;
  g1(46,5)=(-1);
  g1(46,47)=1;
  g1(47,24)=(-(((y(24))-y(24))/((y(24))*(y(24)))));
  g1(47,42)=1;
  g1(48,29)=(-(((y(29))-y(29))/((y(29))*(y(29)))));
  g1(48,48)=1;
  g1(49,23)=(-(((y(23))-y(23))/((y(23))*(y(23)))));
  g1(49,49)=1;
  g1(50,22)=(-(((y(22))-y(22))/((y(22))*(y(22)))));
  g1(50,50)=1;
  g1(51,7)=(-(((y(7))-y(7))/((y(7))*(y(7)))));
  g1(51,51)=1;
  g1(52,6)=(-(((y(6))-y(6))/((y(6))*(y(6)))));
  g1(52,52)=1;
  g1(53,16)=(-(((y(16))-y(16))/((y(16))*(y(16)))));
  g1(53,53)=1;
  g1(54,28)=(-(((y(28))-y(28))/((y(28))*(y(28)))));
  g1(54,54)=1;
  g1(55,8)=(-(((y(8))-y(8))/((y(8))*(y(8)))));
  g1(55,55)=1;
  g1(56,9)=(-(((y(9))-y(9))/((y(9))*(y(9)))));
  g1(56,56)=1;
  g1(57,21)=(-(((y(21))-y(21))/((y(21))*(y(21)))));
  g1(57,57)=1;
  g1(58,43)=(-(((y(43))-y(43))/((y(43))*(y(43)))));
  g1(58,58)=1;
  g1(59,44)=(-(((y(44))-y(44))/((y(44))*(y(44)))));
  g1(59,59)=1;
  g1(60,46)=(-(((y(46))-y(46))/((y(46))*(y(46)))));
  g1(60,60)=1;
  g1(61,1)=(-(((y(1))-y(1))/((y(1))*(y(1)))));
  g1(61,67)=1;
  g1(62,2)=(-(((y(2))-y(2))/((y(2))*(y(2)))));
  g1(62,68)=1;
  g1(63,19)=(-(((y(19))-y(19))/((y(19))*(y(19)))));
  g1(63,69)=1;
  g1(64,20)=(-(((y(20))-y(20))/((y(20))*(y(20)))));
  g1(64,70)=1;
  g1(65,3)=(-4);
  g1(65,10)=4;
  g1(65,61)=1;
  g1(66,3)=(-4);
  g1(66,62)=1;
  g1(67,10)=(-4);
  g1(67,63)=1;
  g1(68,3)=(-4);
  g1(68,64)=1;
  g1(69,3)=(-4);
  g1(69,65)=1;
  g1(70,5)=(-4);
  g1(70,66)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],70,4900);
end
end
